var logLib = require('../lib/logger');
var Moment = require('moment');
var price = require('format-price');

var reverse = require('reverse-string');

var log = logLib.logger('labelprint_textFieldType');
/**
 * writes content of label
 * 
 * @param type
 * @param sale
 * @param textFieldConfig
 */
module.exports.content = function (type, sale, textFieldConfig) {
	if (type === 'productNumber') {
		if (sale.hasOwnProperty('product') && sale.product.hasOwnProperty('number')) {
			return sale.product.number;
		}
		return '';
	}

	if (type === 'saleRecognitionCode') {
		if (sale.hasOwnProperty('recognitionCode')) {
			return sale.recognitionCode;
		}
		return '';
	}

	if (type === 'productDescription') {
		if (sale.hasOwnProperty('product') && sale.product.hasOwnProperty('name')) {
			return sale.product.name;
		}
		return '';
	}

	if (type === 'saleDescription') {
		return sale.description;
	}

	if (type === 'productPrice') {
		var isoCode = textFieldConfig.isoCode
		if (isoCode === 'CHF')
			return price.format('de-CH', 'CHF', sale.price);
		return price.format('de-DE', 'EUR', sale.price);
	}

	if (type === 'expirationDate') {
		if (sale.product.hasOwnProperty('texts') && sale.product.texts.hasOwnProperty('warrantyText')) {
			var receiptDate = new Moment(sale.bookingTime, 'YYYY-MM-DDTHH:mm:ss.SSSZZ');
			receiptDate.hours(sale.product.texts.warrantyText);
			return receiptDate.format(textFieldConfig.dateFormat);
		}
		return '';
	}

	if (type === 'text') {
		return textFieldConfig.text;
	}



	if (type === 'actualDate') {
		if (textFieldConfig.reverseText && textFieldConfig.reverseText !== null && (textFieldConfig.reverseText !== true || textFieldConfig.reverseText !== 'true'))
			return reverse(Moment().format(textFieldConfig.dateFormat));
		return Moment().format(textFieldConfig.dateFormat);
	}

	if (type === 'descriptionText') {
		if (sale.product.hasOwnProperty('texts') && sale.product.texts.hasOwnProperty('description')) {
			return sale.product.texts.description;
		}
		return '';
	}
	if (type === 'receiptText') {
		if (sale.product.hasOwnProperty('texts') && sale.product.texts.hasOwnProperty('receiptText')) {
			return sale.product.texts.receiptText;
		}
		return '';
	}
	if (type === 'orderText') {
		if (sale.product.hasOwnProperty('texts') && sale.product.texts.hasOwnProperty('orderText')) {
			return sale.product.texts.orderText;
		}
		return '';
	}
	if (type === 'recipeText') {
		if (sale.product.hasOwnProperty('texts') && sale.product.texts.hasOwnProperty('recipe')) {
			return sale.product.texts.recipe;
		}
		return '';
	}
	if (type === 'ingredientsText') {
		if (sale.product.hasOwnProperty('texts') && sale.product.texts.hasOwnProperty('ingredients')) {
			return sale.product.texts.ingredients;
		}
		return '';
	}
	if (type === 'allergenText') {
		if (sale.product.hasOwnProperty('texts') && sale.product.texts.hasOwnProperty('allergens')) {
			return sale.product.texts.allergens;
		}
		return '';
	}
	if (type === 'additiveText') {
		if (sale.product.hasOwnProperty('texts') && sale.product.texts.hasOwnProperty('additives')) {
			return sale.product.texts.additives;
		}
		return '';
	}
	if (type === 'nutritionText') {
		if (sale.product.hasOwnProperty('texts') && sale.product.texts.hasOwnProperty('nutritionalValue')) {
			return sale.product.texts.nutritionalValue;
		}
		return '';
	}
	if (type === 'careText') {
		if (sale.product.hasOwnProperty('texts') && sale.product.texts.hasOwnProperty('careInstructions')) {
			return sale.product.texts.careInstructions;
		}
		return '';
	}
	if (type === 'instructionText') {
		if (sale.product.hasOwnProperty('texts') && sale.product.texts.hasOwnProperty('manual')) {
			return sale.product.texts.manual;
		}
		return '';
	}
	if (type === 'certificateText') {
		if (sale.product.hasOwnProperty('texts') && sale.product.texts.hasOwnProperty('certificate')) {
			return sale.product.texts.certificate;
		}
		return '';
	}
	if (type === 'warrantyText') {
		if (sale.product.hasOwnProperty('texts') && sale.product.texts.hasOwnProperty('warrantyText')) {
			return sale.product.texts.warrantyText;
		}
		return '';
	}

	return 'unknown Field';
};